@@ -13,6 +13,18 @@ def dfis_to_postgre(dfis,
                     port=5432,
                     db_name=None,
                     text_file_with_url=None):
+    for dfi in dfis:
+        dfi.name = 'discord_' + dfi.name
+    base_dfis_to_postgre(dfis, if_exists, username, password, host, port, db_name, text_file_with_url)
+
+def base_dfis_to_postgre(dfis,
+                    if_exists,
+                    username=None,
+                    password=None,
+                    host=None,
+                    port=5432,
+                    db_name=None,
+                    text_file_with_url=None):
     if text_file_with_url:
         with open(text_file_with_url, 'r') as url_fo:
             engine = create_engine(url_fo.read().strip())
@@ -24,8 +36,8 @@ def dfis_to_postgre(dfis,
             slice_columns(dfi)
             print('Inserting %s df to db...' % dfi.name)
             dfi.df.to_sql(
-                'discord_' + dfi.name,
+                dfi.name,
                 engine,
                 if_exists=if_exists,
                 dtype=dfi.datatypes,
-                index=False)
\ No newline at end of file
+                index=False)
